@@ -30,6 +30,15 @@
 #include <stdlib.h>
 #include <string.h>
 
+/*
+ * @brief Struct allocating memory space for flash regions. Used by
+ * rtems_flashdev to store region allocations.
+ */
+typedef struct zqspi_flash_region_table {
+  rtems_flashdev_region zqspi_flash_regions[ZQSPI_FLASH_MAX_REGIONS];
+  uint32_t zqspi_flash_bit_allocator;
+} zqspi_flash_region_table;
+
 static uint32_t zqspi_get_jedec_id(rtems_flashdev *flash) {
   uint32_t jedec = 0;
   zqspi_readid(flash->driver, &jedec);
@@ -147,6 +156,12 @@ static int zqspi_sector_count(
   return 0;
 }
 
+static void zqspi_priv_destroy(rtems_flashdev* flash)
+{
+  free(flash->region_table->regions);
+  free(flash->region_table);
+}
+
 rtems_flashdev* zqspi_flashdev_init(zqspiflash *bmdriver)
 {
   zqspi_flash_region_table *xtable =
@@ -178,6 +193,7 @@ rtems_flashdev* zqspi_flashdev_init(zqspiflash *bmdriver)
   }
 
   flash->driver = bmdriver;
+  flash->priv_destroy = &zqspi_priv_destroy;
   flash->read = &zqspi_read_wrapper;
   flash->write = &zqspi_write_wrapper;
   flash->erase = &zqspi_erase_wrapper;
@@ -193,10 +209,3 @@ rtems_flashdev* zqspi_flashdev_init(zqspiflash *bmdriver)
 
   return flash;
 }
-
-void zqspi_flashdev_destroy(rtems_flashdev* flash)
-{
-  free(flash->region_table->regions);
-  free(flash->region_table);
-  rtems_flashdev_destroy_and_free(flash);
-}
