@@ -32,6 +32,15 @@
 #include <stdlib.h>
 #include <string.h>
 
+/*
+ * @brief Struct allocating memory space for flash regions. Used by
+ * rtems_flashdev to store region allocations.
+ */
+typedef struct xqspi_flash_region_table {
+  rtems_flashdev_region xqspi_flash_regions[XQSPI_FLASH_MAX_REGIONS];
+  uint32_t xqspi_flash_bit_allocator;
+} xqspi_flash_region_table;
+
 static uint32_t xqspi_get_jedec_id(rtems_flashdev *flash) {
   return QspiPsu_NOR_Get_JEDEC_ID(flash->driver);
 }
@@ -90,6 +99,28 @@ static int xqspi_page_count(
   return 0;
 }
 
+static int xqspi_sector_count(
+  rtems_flashdev *flash,
+  int *sector_count
+)
+{
+  *sector_count = QspiPsu_NOR_Get_Device_Size(flash->driver) /
+                  QspiPsu_NOR_Get_Sector_Size(flash->driver);
+  return 0;
+}
+
+static int xqspi_sector_info_by_off(
+  rtems_flashdev *flash,
+  off_t search_offset,
+  off_t *sector_offset,
+  size_t *sector_size
+)
+{
+  *sector_size = QspiPsu_NOR_Get_Sector_Size(flash->driver);
+  *sector_offset = search_offset - (search_offset%((off_t)(*sector_size)));
+  return 0;
+}
+
 static int xqspi_write_block_size(
   rtems_flashdev *flash,
   size_t *write_block_size
@@ -121,6 +152,12 @@ static int xqspi_erase_wrapper(
   return QspiPsu_NOR_Erase(flash_driver, (uint32_t)offset, (uint32_t)count);
 }
 
+static void xqspi_flash_priv_destroy(rtems_flashdev* flash)
+{
+  free(flash->region_table->regions);
+  free(flash->region_table);
+}
+
 rtems_flashdev* xqspi_flash_init(XQspiPsu *xQspiDev)
 {
   xqspi_flash_region_table *xtable =
@@ -152,6 +189,7 @@ rtems_flashdev* xqspi_flash_init(XQspiPsu *xQspiDev)
   }
 
   flash->driver = xQspiDev;
+  flash->priv_destroy = &xqspi_flash_priv_destroy;
   flash->read = &xqspi_read_wrapper;
   flash->write = &xqspi_write_wrapper;
   flash->erase = &xqspi_erase_wrapper;
@@ -161,14 +199,9 @@ rtems_flashdev* xqspi_flash_init(XQspiPsu *xQspiDev)
   flash->page_info_by_index = &xqspi_page_info_by_index;
   flash->page_count = &xqspi_page_count;
   flash->write_block_size = &xqspi_write_block_size;
+  flash->sector_count = &xqspi_sector_count;
+  flash->sector_info_by_offset = &xqspi_sector_info_by_off;
   flash->region_table = ftable;
 
   return flash;
 }
-
-void xqspi_flash_destroy(rtems_flashdev* flash)
-{
-  free(flash->region_table->regions);
-  free(flash->region_table);
-  rtems_flashdev_destroy_and_free(flash);
-}
